com

package
v0.0.0-...-8b2d73a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2018 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Copyright 2018, RadiantBlue Technologies, Inc.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

const DependenciesField = `dependencies`
const DependencyScanMapping string = `{
	"dynamic":"strict",
	"properties":{
		"full_name":{"type":"keyword"},
		"name":{"type":"keyword"},
		"refs":{"type":"keyword"},
		"sha":{"type":"keyword"},
		"timestamp":{"type":"keyword"},
		"dependencies":` + d.DependencyMapping + `,
		"issues":{"type":"keyword"},
		"files":{"type":"keyword"}
	}
}`
const FilesField = `files`
const FullNameField = `full_name`
const IssuesField = `issues`
const NameField = `name`
const RefsField = `refs`
const ShaField = `sha`
const TimestampField = `timestamp`

Variables

This section is empty.

Functions

This section is empty.

Types

type DependencyScan

type DependencyScan struct {
	Fullname  string         `json:"full_name"`
	Name      string         `json:"name"`
	Sha       string         `json:"sha"`
	Refs      []string       `json:"refs"`
	Deps      []d.Dependency `json:"dependencies"`
	Issues    []string       `json:"issues"`
	Files     []string       `json:"files"`
	Timestamp time.Time      `json:"timestamp"`
}

type DependencyScans

type DependencyScans map[string]DependencyScan

Directories

Path Synopsis

Jump to